package com.example.refactor.adapter;

import com.example.refactor.entity.User;
import com.example.refactor.entity.v2.EmployeeInfo;
import com.example.refactor.entity.v2.UserProfile;
import com.example.refactor.entity.v2.UserSecurity;

/**
 * 用户适配器接口
 * 职责：定义新旧User实体之间的转换规范
 */
public interface UserAdapter {
    
    /**
     * 将旧的User实体转换为新的UserProfile
     */
    UserProfile toUserProfile(User user);
    
    /**
     * 将旧的User实体转换为新的EmployeeInfo
     */
    EmployeeInfo toEmployeeInfo(User user, UserProfile userProfile);
    
    /**
     * 将旧的User实体转换为新的UserSecurity
     */
    UserSecurity toUserSecurity(User user, UserProfile userProfile);
    
    /**
     * 将新的实体组合转换为旧的User实体（向后兼容）
     */
    User toLegacyUser(UserProfile userProfile, EmployeeInfo employeeInfo, UserSecurity userSecurity);
    
    /**
     * 部分转换：只转换基础信息
     */
    User toLegacyUserBasic(UserProfile userProfile, UserSecurity userSecurity);
}