package com.example.refactor.entity;

import javax.persistence.*;
import java.util.Date;

/**
 * 用户快照实体类
 * 用于存储用户数据的快照版本
 */
@Entity
@Table(name = "user_snapshots")
public class UserSnapshot {
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;
    
    @Column(nullable = false)
    private String snapshotId;  // 快照唯一标识
    
    @Column(nullable = false)
    private Long userId;  // 关联的用户ID
    
    private String name;
    private String email;
    private String phone;
    private Date createTime;
    private Date updateTime;
    
    // 业务相关字段
    private String department;
    private String position;
    private Double salary;
    private String address;
    private String emergencyContact;
    
    // 系统字段
    private String status;
    private String lastLoginIp;
    private Date lastLoginTime;
    
    @Temporal(TemporalType.TIMESTAMP)
    private Date snapshotCreateTime;  // 快照创建时间
    
    private String snapshotReason;  // 快照创建原因
    
    public UserSnapshot() {
        this.snapshotCreateTime = new Date();
    }
    
    public UserSnapshot(String snapshotId, Long userId) {
        this.snapshotId = snapshotId;
        this.userId = userId;
        this.snapshotCreateTime = new Date();
    }
    
    // 从User实体创建快照
    public static UserSnapshot fromUser(User user, String snapshotId, String reason) {
        UserSnapshot snapshot = new UserSnapshot(snapshotId, user.getId());
        snapshot.setName(user.getName());
        snapshot.setEmail(user.getEmail());
        snapshot.setPhone(user.getPhone());
        snapshot.setCreateTime(user.getCreateTime());
        snapshot.setUpdateTime(user.getUpdateTime());
        snapshot.setDepartment(user.getDepartment());
        snapshot.setPosition(user.getPosition());
        snapshot.setSalary(user.getSalary());
        snapshot.setAddress(user.getAddress());
        snapshot.setEmergencyContact(user.getEmergencyContact());
        snapshot.setStatus(user.getStatus());
        snapshot.setLastLoginIp(user.getLastLoginIp());
        snapshot.setLastLoginTime(user.getLastLoginTime());
        snapshot.setSnapshotReason(reason);
        return snapshot;
    }
    
    // 将快照转换为User实体
    public User toUser() {
        User user = new User();
        user.setId(this.userId);
        user.setName(this.name);
        user.setEmail(this.email);
        user.setPhone(this.phone);
        user.setCreateTime(this.createTime);
        user.setUpdateTime(this.updateTime);
        user.setDepartment(this.department);
        user.setPosition(this.position);
        user.setSalary(this.salary);
        user.setAddress(this.address);
        user.setEmergencyContact(this.emergencyContact);
        user.setStatus(this.status);
        user.setLastLoginIp(this.lastLoginIp);
        user.setLastLoginTime(this.lastLoginTime);
        user.setSnapshotId(this.snapshotId);
        return user;
    }
    
    // Getters and Setters
    public Long getId() { return id; }
    public void setId(Long id) { this.id = id; }
    
    public String getSnapshotId() { return snapshotId; }
    public void setSnapshotId(String snapshotId) { this.snapshotId = snapshotId; }
    
    public Long getUserId() { return userId; }
    public void setUserId(Long userId) { this.userId = userId; }
    
    public String getName() { return name; }
    public void setName(String name) { this.name = name; }
    
    public String getEmail() { return email; }
    public void setEmail(String email) { this.email = email; }
    
    public String getPhone() { return phone; }
    public void setPhone(String phone) { this.phone = phone; }
    
    public Date getCreateTime() { return createTime; }
    public void setCreateTime(Date createTime) { this.createTime = createTime; }
    
    public Date getUpdateTime() { return updateTime; }
    public void setUpdateTime(Date updateTime) { this.updateTime = updateTime; }
    
    public String getDepartment() { return department; }
    public void setDepartment(String department) { this.department = department; }
    
    public String getPosition() { return position; }
    public void setPosition(String position) { this.position = position; }
    
    public Double getSalary() { return salary; }
    public void setSalary(Double salary) { this.salary = salary; }
    
    public String getAddress() { return address; }
    public void setAddress(String address) { this.address = address; }
    
    public String getEmergencyContact() { return emergencyContact; }
    public void setEmergencyContact(String emergencyContact) { this.emergencyContact = emergencyContact; }
    
    public String getStatus() { return status; }
    public void setStatus(String status) { this.status = status; }
    
    public String getLastLoginIp() { return lastLoginIp; }
    public void setLastLoginIp(String lastLoginIp) { this.lastLoginIp = lastLoginIp; }
    
    public Date getLastLoginTime() { return lastLoginTime; }
    public void setLastLoginTime(Date lastLoginTime) { this.lastLoginTime = lastLoginTime; }
    
    public Date getSnapshotCreateTime() { return snapshotCreateTime; }
    public void setSnapshotCreateTime(Date snapshotCreateTime) { this.snapshotCreateTime = snapshotCreateTime; }
    
    public String getSnapshotReason() { return snapshotReason; }
    public void setSnapshotReason(String snapshotReason) { this.snapshotReason = snapshotReason; }
} 