package com.example.refactor.repository;

import com.example.refactor.entity.User;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import java.util.Date;
import java.util.List;

@Repository
public interface UserRepository extends JpaRepository<User, Long> {
    
    List<User> findByStatus(String status);
    
    List<User> findByDepartment(String department);
    
    @Query("SELECT u FROM User u WHERE u.email = ?1")
    User findByEmail(String email);
    
    @Query("SELECT u FROM User u WHERE u.name LIKE %?1%")
    List<User> findByNameContaining(String name);
    
    /**
     * 根据快照ID查找用户
     */
    List<User> findBySnapshotId(String snapshotId);
    
    /**
     * 查找没有使用快照的用户（snapshotId为空）
     */
    List<User> findBySnapshotIdIsNull();
    
    /**
     * 查找使用快照的用户（snapshotId不为空）
     */
    List<User> findBySnapshotIdIsNotNull();
    
    /**
     * 根据登录时间查找用户
     */
    List<User> findByLastLoginTimeAfter(Date since);
}