package com.example.refactor.repository;

import com.example.refactor.entity.UserSnapshot;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Optional;

@Repository
public interface UserSnapshotRepository extends JpaRepository<UserSnapshot, Long> {
    
    /**
     * 根据快照ID查找快照
     */
    Optional<UserSnapshot> findBySnapshotId(String snapshotId);
    
    /**
     * 根据用户ID查找该用户的所有快照
     */
    List<UserSnapshot> findByUserIdOrderBySnapshotCreateTimeDesc(Long userId);
    
    /**
     * 根据用户ID和快照ID查找特定快照
     */
    Optional<UserSnapshot> findByUserIdAndSnapshotId(Long userId, String snapshotId);
    
    /**
     * 查找用户的最新快照
     */
    @Query("SELECT us FROM UserSnapshot us WHERE us.userId = ?1 ORDER BY us.snapshotCreateTime DESC")
    Optional<UserSnapshot> findLatestByUserId(Long userId);
    
    /**
     * 检查快照ID是否存在
     */
    boolean existsBySnapshotId(String snapshotId);
    
    /**
     * 根据快照创建原因查找快照
     */
    List<UserSnapshot> findBySnapshotReasonContaining(String reason);
} 