package com.example.refactor.service;

import com.example.refactor.entity.User;
import com.example.refactor.repository.v2.EmployeeInfoRepository;
import com.example.refactor.service.v2.UserFacadeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * HR服务V2 - 使用新架构的实现
 */
@Service
@Primary
@ConditionalOnProperty(name = "app.user.architecture", havingValue = "v2", matchIfMissing = false)
public class HRServiceV2 {
    
    @Autowired
    private UserFacadeService userFacadeService;
    
    @Autowired
    private EmployeeInfoRepository employeeInfoRepository;
    
    public User updateEmployeeInfo(Long userId, String department, String position, Double salary) {
        return userFacadeService.updateEmployeeInfo(userId, department, position, salary);
    }
    
    public List<User> getEmployeesByDepartment(String department) {
        return userFacadeService.getEmployeesByDepartment(department);
    }
    
    public User promoteEmployee(Long userId, String newPosition, Double newSalary) {
        User currentUser = userFacadeService.getUserById(userId);
        if (currentUser != null) {
            return userFacadeService.updateEmployeeInfo(userId, currentUser.getDepartment(), newPosition, newSalary);
        }
        return null;
    }
    
    public User transferEmployee(Long userId, String newDepartment) {
        User currentUser = userFacadeService.getUserById(userId);
        if (currentUser != null) {
            return userFacadeService.updateEmployeeInfo(userId, newDepartment, currentUser.getPosition(), currentUser.getSalary());
        }
        return null;
    }
    
    public Double calculateTotalSalaryByDepartment(String department) {
        Double total = employeeInfoRepository.getTotalSalaryByDepartment(department);
        return total != null ? total : 0.0;
    }
}